proc test_unlist {} {
    set list {foo bar baz}
    unlist $list a b
    if {$a != "foo"} { error "a not set correctly" }
    if {$b != "bar"} { error "b not set correctly" }

    unlist $list c d e f
    if {$c != "foo"} { error "c not set correctly" }
    if {$d != "bar"} { error "d not set correctly" }
    if {$e != "baz"} { error "d not set correctly" }
    if {$f != ""} { error "f not set correctly" }
}

proc test_md5 {} {
    if {[dqd_md5 "this is a string"] != "b37e16c620c055cf8207b999e3270e9b"} {
	error "wrong md5 hash"
    }
}

proc test_nssetToList {} {
    set set [ns_set new]

    dqd_nssetToList $set list
    if {$list != ""} {
	error "wrong list for empty set"
    }

    ns_set put $set foo bar
    dqd_nssetToList $set list
    if {$list != "bar"} {
	error "wrong list for {{foo bar}}"
    }

    ns_set put $set x {y z}
    dqd_nssetToList $set list
    if {$list != "bar {y z}"} {
	error "wrong list for {{foo bar} {x {y z}}}"
    }
}

proc checkChannel {cid} {
    seek $cid 0
    set line [gets $cid]
    if {$line != "test string"} {
	error "bad string from $cid"
    }
}

proc test_detach {} {
    ns_log Debug "attaching sharedFile"
    set cid [dqd_attachfile sharedFile]
    ns_log Debug "attached to $cid"
    checkChannel $cid
    ns_log Debug "detaching $cid"
    dqd_detachfile $cid sharedFile
}

proc init_detach {} {
    set cid [open "testfile" r]
    checkChannel $cid
    dqd_detachfile $cid sharedFile
}

proc run_test {test} {
    $test
    ns_return 200 text/plain "ok\n"
}

foreach test [info procs test_*] {
    ns_log Debug "registering $test"
    ns_register_proc -noinherit GET "/$test" run_test $test
}

init_detach
